==> owncloud-4.5.7.tgz: owncloud/apps/files/l10n/zh_CN.GB2312.php <==
<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "没有任何错误,文件上传成功了",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "上传的文件超过了php.ini指定的upload_max_filesize",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上传的文件超过了HTML表单指定的MAX_FILE_SIZE",
"The uploaded file was only partially uploaded" => "文件只有部分被上传",
"No file was uploaded" => "没有上传完成的文件",
"Missing a temporary folder" => "丢失了一个临时文件夹",
"Failed to write to disk" => "写磁盘失败",
"Files" => "文件",
"Unshare" => "取消共享",
"Delete" => "删除",
"already exists" => "已经存在了",
"replace" => "替换",
"suggest name" => "推荐名称",
"cancel" => "取消",
"replaced" => "替换过了",
"undo" => "撤销",
"with" => "随着",
"unshared" => "已取消共享",
"deleted" => "删除",
"generating ZIP-file, it may take some time." => "正在生成ZIP文件,这可能需要点时间",
"Unable to upload your file as it is a directory or has 0 bytes" => "不能上传你指定的文件,可能因为它是个文件夹或者大小为0",
"Upload Error" => "上传错误",
"Pending" => "Pending",
"Upload cancelled." => "上传取消了",
"File upload is in progress. Leaving the page now will cancel the upload." => "文件正在上传。关闭页面会取消上传。",
"Invalid name, '/' is not allowed." => "非法文件名,\"/\"是不被许可的",
"files scanned" => "文件已扫描",
"error while scanning" => "扫描出错",
"Name" => "名字",
"Size" => "大小",
"Modified" => "修改日期",
"folder" => "文件夹",
"folders" => "文件夹",
"file" => "文件",
"files" => "文件",
"File handling" => "文件处理中",
"Maximum upload size" => "最大上传大小",
"max. possible: " => "最大可能",
"Needed for multi-file and folder downloads." => "需要多文件和文件夹下载.",
"Enable ZIP-download" => "支持ZIP下载",
"0 is unlimited" => "0是无限的",
"Maximum input size for ZIP files" => "最大的ZIP文件输入大小",
"Save" => "保存",
"New" => "新建",
"Text file" => "文本文档",
"Folder" => "文件夹",
"From url" => "从URL:",
"Upload" => "上传",
"Cancel upload" => "取消上传",
"Nothing in here. Upload something!" => "这里没有东西.上传点什么!",
"Share" => "分享",
"Download" => "下载",
"Upload too large" => "上传的文件太大了",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "你正在试图上传的文件超过了此服务器支持的最大的文件大小.",
"Files are being scanned, please wait." => "正在扫描文件,请稍候.",
"Current scanning" => "正在扫描"
);

==> owncloud-5.0.9.tgz: owncloud/apps/files/l10n/zh_CN.GB2312.php <==
<?php $TRANSLATIONS = array(
"No file was uploaded. Unknown error" => "没有上传文件。未知错误",
"There is no error, the file uploaded with success" => "没有任何错误,文件上传成功了",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上传的文件超过了HTML表单指定的MAX_FILE_SIZE",
"The uploaded file was only partially uploaded" => "文件只有部分被上传",
"No file was uploaded" => "没有上传完成的文件",
"Missing a temporary folder" => "丢失了一个临时文件夹",
"Failed to write to disk" => "写磁盘失败",
"Files" => "文件",
"Share" => "分享",
"Delete" => "删除",
"Rename" => "重命名",
"Pending" => "Pending",
"{new_name} already exists" => "{new_name} 已存在",
"replace" => "替换",
"suggest name" => "推荐名称",
"cancel" => "取消",
"replaced {new_name} with {old_name}" => "已用 {old_name} 替换 {new_name}",
"undo" => "撤销",
"Unable to upload your file as it is a directory or has 0 bytes" => "不能上传你指定的文件,可能因为它是个文件夹或者大小为0",
"Upload Error" => "上传错误",
"Close" => "关闭",
"1 file uploading" => "1 个文件正在上传",
"{count} files uploading" => "{count} 个文件正在上传",
"Upload cancelled." => "上传取消了",
"File upload is in progress. Leaving the page now will cancel the upload." => "文件正在上传。关闭页面会取消上传。",
"URL cannot be empty." => "网址不能为空。",
"Name" => "名字",
"Size" => "大小",
"Modified" => "修改日期",
"1 folder" => "1 个文件夹",
"{count} folders" => "{count} 个文件夹",
"1 file" => "1 个文件",
"{count} files" => "{count} 个文件",
"Upload" => "上传",
"File handling" => "文件处理中",
"Maximum upload size" => "最大上传大小",
"max. possible: " => "最大可能",
"Needed for multi-file and folder downloads." => "需要多文件和文件夹下载.",
"Enable ZIP-download" => "支持ZIP下载",
"0 is unlimited" => "0是无限的",
"Maximum input size for ZIP files" => "最大的ZIP文件输入大小",
"Save" => "保存",
"New" => "新建",
"Text file" => "文本文档",
"Folder" => "文件夹",
"From link" => "来自链接",
"Cancel upload" => "取消上传",
"Nothing in here. Upload something!" => "这里没有东西.上传点什么!",
"Download" => "下载",
"Unshare" => "取消共享",
"Upload too large" => "上传的文件太大了",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "你正在试图上传的文件超过了此服务器支持的最大的文件大小.",
"Files are being scanned, please wait." => "正在扫描文件,请稍候.",
"Current scanning" => "正在扫描"
);
